==> haskell-retry-0.8.0.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-retry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: retry
version: 0.8.0.1
id: retry-0.8.0.1-9s8WKr0LPPbC3x1nkKdYtD
key: retry-0.8.0.1-9s8WKr0LPPbC3x1nkKdYtD
license: BSD-3-Clause
copyright: Ozgun Ataman, Soostone Inc
maintainer: ozgun.ataman@soostone.com
author: Ozgun Ataman
homepage: http://github.com/Soostone/retry
synopsis: Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.
category: Control
abi: 5f6c7cb5e249b76d8be104216b69048e
exposed: True
exposed-modules:
    Control.Retry
import-dirs: /usr/lib/ghc-8.6.5/site-local/retry-0.8.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/retry-0.8.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/retry-0.8.0.1
hs-libraries: HSretry-0.8.0.1-9s8WKr0LPPbC3x1nkKdYtD
depends:
    base-4.12.0.0 exceptions-0.10.2-Gj8cIuYcXhQEAym4RMvM4g
    ghc-prim-0.5.3 random-1.1-3ypV4EIycgb35PKjTYYr5q
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html: /usr/share/doc/haskell-retry/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-retry-0.8.0.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-retry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: retry
version: 0.8.0.1
id: retry-0.8.0.1-7oxh2EblWH3Kwrvq5mdjEX
key: retry-0.8.0.1-7oxh2EblWH3Kwrvq5mdjEX
license: BSD-3-Clause
copyright: Ozgun Ataman, Soostone Inc
maintainer: ozgun.ataman@soostone.com
author: Ozgun Ataman
homepage: http://github.com/Soostone/retry
synopsis: Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.
category: Control
abi: 5bdae7ec2b4eb860e5e603466598bebe
exposed: True
exposed-modules:
    Control.Retry
import-dirs: /usr/lib/ghc-8.6.5/site-local/retry-0.8.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/retry-0.8.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/retry-0.8.0.1
hs-libraries: HSretry-0.8.0.1-7oxh2EblWH3Kwrvq5mdjEX
depends:
    base-4.12.0.0 exceptions-0.10.2-5svhVYbSwFFKlwgRdeEWGk
    ghc-prim-0.5.3 random-1.1-3ypV4EIycgb35PKjTYYr5q
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html: /usr/share/doc/haskell-retry/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
